/**********************************************************************
Copyright (c) 2006 Erik Bengtson and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 

Contributors:
2006 Andy Jefferson - javadocs
    ...
**********************************************************************/
package org.datanucleus.jpa;

import java.util.Map;

import javax.persistence.EntityManagerFactory;
import javax.persistence.spi.PersistenceProvider;
import javax.persistence.spi.PersistenceUnitInfo;

import org.datanucleus.jpa.exceptions.NoPersistenceUnitException;
import org.datanucleus.jpa.exceptions.NoPersistenceXmlException;
import org.datanucleus.jpa.exceptions.NotProviderException;

/**
 * PersistenceProvider implementation.
 * Provides a means of creating EntityManagerFactory objects.
 */
public class PersistenceProviderImpl implements PersistenceProvider
{
    /**
     * Constructor.
     */
    public PersistenceProviderImpl()
    {
    }

    /**
     * Method to create an EntityManagerFactory when running in J2EE.
     * The container will have parsed the persistence.xml files to provide this PersistenceUnitInfo.
     * @param unitInfo The "persistence-unit"
     * @param properties EntityManagerFactory properties to override those in the persistence unit
     * @return The EntityManagerFactory
     */
    public EntityManagerFactory createContainerEntityManagerFactory(PersistenceUnitInfo unitInfo, Map properties)
    {
        try
        {
            EntityManagerFactoryImpl emf = new EntityManagerFactoryImpl(unitInfo, properties);
            return emf;
        }
        catch (NotProviderException npe)
        {
            return null;
        }
    }

    /**
     * Method to create an EntityManagerFactory when running in J2SE.
     * @param unitName Name of the "persistence-unit"
     * @param properties EntityManagerFactory properties to override those in the persistence unit
     * @return The EntityManagerFactory
     */
    public EntityManagerFactory createEntityManagerFactory(String unitName, Map properties)
    {
        try
        {
            EntityManagerFactoryImpl emf = new EntityManagerFactoryImpl(unitName, properties);
            return emf;
        }
        catch (NotProviderException npe)
        {
            return null;
        }
        catch (NoPersistenceUnitException npue)
        {
            return null;
        }
        catch (NoPersistenceXmlException npxe)
        {
            return null;
        }
    }
}